@@ -82,8 +82,6 @@ fn test_ok_host_synthesizable() {
     uut.hi.sig_aa.connect();
     uut.connect_all();
     let vlog = generate_verilog(&uut);
-    println!("{}", vlog);
     let ucf = crate::toolchain::ise::generate_ucf(&uut);
-    println!("{}", ucf);
     yosys_validate("vlog", &vlog).unwrap();
 }
