@@ -6,6 +6,7 @@ use std::time::Duration;
 #[derive(LogicBlock)]
 pub struct Pulser {
     pub clock: Signal<In, Clock>,
+    pub reset: Signal<In, Reset>,
     pub enable: Signal<In, Bit>,
     pub pulse: Signal<Out, Bit>,
     strobe: Strobe<32>,
@@ -18,6 +19,7 @@ impl Pulser {
         let shot = Shot::new(clock_rate_hz, pulse_duration);
         Self {
             clock: Signal::default(),
+            reset: Default::default(),
             enable: Signal::default(),
             pulse: Signal::new_with_default(false),
             strobe,
@@ -29,8 +31,7 @@ impl Pulser {
 impl Logic for Pulser {
     #[hdl_gen]
     fn update(&mut self) {
-        self.strobe.clock.next = self.clock.val();
-        self.shot.clock.next = self.clock.val();
+        clock_reset!(self, clock, reset, strobe, shot);
         self.strobe.enable.next = self.enable.val();
         self.shot.trigger.next = self.strobe.strobe.val();
         self.pulse.next = self.shot.active.val();
@@ -41,10 +42,10 @@ impl Logic for Pulser {
 fn test_pulser_synthesis() {
     let mut uut = Pulser::new(1_000_000, 1.0, Duration::from_millis(100));
     uut.clock.connect();
+    uut.reset.connect();
     uut.enable.connect();
     uut.connect_all();
     let vlog = generate_verilog(&uut);
-    println!("{}", vlog);
     yosys_validate("pulser", &vlog).unwrap();
 }
 
@@ -55,19 +56,30 @@ fn test_pulser() {
     sim.add_clock(5, |x: &mut Box<Pulser>| x.clock.next = !x.clock.val());
     sim.add_testbench(|mut sim: Sim<Pulser>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         x.enable.next = true;
         x = sim.wait(100_000, x)?;
         sim.done(x)?;
         Ok(())
     });
-    let mut uut = Pulser::new(KHZ10, 100.0, Duration::from_millis(100));
+    sim.add_testbench(|mut sim: Sim<Pulser>| {
+        let mut x = sim.init()?;
+        for _j in 0..20 {
+            x = sim.watch(|x| x.pulse.val(), x)?;
+            for _i in 0..10 {
+                wait_clock_cycle!(sim, clock, x);
+                sim_assert!(sim, x.pulse.val(), x);
+            }
+            wait_clock_cycle!(sim, clock, x);
+            sim_assert!(sim, !x.pulse.val(), x);
+        }
+        sim.done(x)?;
+        Ok(())
+    });
+    let mut uut = Pulser::new(KHZ10, 100.0, Duration::from_millis(1));
     uut.clock.connect();
+    uut.reset.connect();
     uut.enable.connect();
     uut.connect_all();
-    sim.run_traced(
-        Box::new(uut),
-        1_000_000,
-        std::fs::File::create("/tmp/pulser.vcd").unwrap(),
-    )
-    .unwrap();
+    sim.run(Box::new(uut), 1_000_000).unwrap();
 }
