@@ -1,10 +1,7 @@
 use rust_hdl::bsp::ok_xem6010::XEM6010;
 use rust_hdl::core::prelude::*;
-use rust_hdl::widgets::prelude::*;
 #[cfg(feature = "frontpanel")]
 use test_common::mux_spi::*;
-#[cfg(feature = "frontpanel")]
-use test_common::tools::*;
 
 mod test_common;
 
